@@ -208,4 +208,4 @@ class qa_burst_sdcch_subslot_filter (gr_unittest.TestCase):
 
 
 if __name__ == '__main__':
-    gr_unittest.run(qa_burst_sdcch_subslot_filter, "qa_burst_sdcch_subslot_filter.xml")
+    gr_unittest.run(qa_burst_sdcch_subslot_filter)
