@@ -1,9 +1,13 @@
 #!/bin/bash
 
-TEST_DIR=`dirname "$0"`
+TEST_DIR=$(dirname "$0")
 
 # PYTHONPATH and LD_LIBRARY_PATH are needed on Fedora 26
-export PYTHONPATH=/usr/local/lib64/python2.7/site-packages/:/usr/local/lib64/python2.7/site-packages/grgsm/:$PYTHONPATH
+#
+# /usr/local/lib/python3/dist-packages/ is currently needed on Debian Testing and Kali Rolling
+# https://salsa.debian.org/bottoms/pkg-gnuradio/blob/unstable/debian/patches/debian-python-install#L8
+#
+export PYTHONPATH=/usr/local/lib/python3/dist-packages/:/usr/local/lib64/python2.7/site-packages/:/usr/local/lib64/python2.7/site-packages/grgsm/:$PYTHONPATH
 export LD_LIBRARY_PATH=/usr/local/lib64/:$LD_LIBRARY_PATH
 
 export AP_DECODE="grgsm_decode"
@@ -14,12 +18,20 @@ export RESULT_OBTAINED="grgsm_decode_test1_result"
 export RUNLINE="$AP_DECODE -c $SHORTENED_CAPFILE -s $((100000000/174)) -m BCCH -t 0 -v --ppm -10"
 echo "Testing with:"
 echo "  $RUNLINE"
-gnuradio-companion --version
+gnuradio-config-info --version
+cat /proc/cpuinfo
+ulimit -a
 
-cd $TEST_DIR
-cat $CAPFILE | head -c 6000000 > $SHORTENED_CAPFILE
+cd "$TEST_DIR" || exit 1
+head -c 6000000 $CAPFILE  > $SHORTENED_CAPFILE
+
+# VOLK_GENERIC=1 is a temporary workaround for the following VOLK's bug
+# https://github.com/gnuradio/volk/pull/278
+# https://github.com/gnuradio/gnuradio/issues/2748
+export VOLK_GENERIC=1
 
 $RUNLINE | grep -A 999999 "860933 1329237:  59 06 1a 8f 6d 18 10 80 00 00 00 00 00 00 00 00 00 00 00 78 b9 00 00" | tee $RESULT_OBTAINED
+
 diff $RESULT_EXPECTED $RESULT_OBTAINED
 TEST_RESULT=$?
 
